%define fakename	qwtplot3d

%define commit		b2655743d30ed3185f3c0e2626b33a1d29655216
%define commitdate	20210828

# Qt5 libraries
%define major_qt5	0.3
%define libname_qt5	%mklibname %{fakename}-qt5_ %{major_qt5}
%define libnamedev_qt5	%mklibname %{fakename}-qt5 -d
# Qt6 libraries
%define major_qt6	0.3
%define libname_qt6	%mklibname %{fakename}-qt6_ %{major_qt6}
%define libnamedev_qt6	%mklibname %{fakename}-qt6 -d

%bcond_without	qt5
%bcond_without	qt6

%define rel	3

Name:		libqwtplot3d
Version:	0.3.1a
Release:	%mkrel 2.git%{commitdate}.%{rel}
Summary:	3D plotting widget extension to the Qt GUI
License:	zlib
Group:		System/Libraries
Url:		https://github.com/SciDAVis/qwtplot3d
Source0:	%{url}/archive/%{commit}/%{fakename}-%{commit}.tar.gz

Patch0:		%{fakename}-qt6-build.patch
Patch1:		%{fakename}-qt5-build.patch

### Qt6 build dependencies
%if %{with qt6}
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
%endif
### Qt5 build dependencies
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5OpenGL)
%endif
#
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gl2ps-devel
BuildRequires:	chrpath

%description
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

#------------------------------------------------------------------------------
### Qt5 ###

%if %{with qt5}
%package -n	%{libname_qt5}
Summary:	Extended version of the original QwtPlot3D Qt5 library
Group:		System/Libraries

# drop old and no more needed Qt4 libs
Obsoletes:	%{_lib}qwtplot3d0 < 0.2.7-17

%description -n	%{libname_qt5}
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

%package -n	%{libnamedev_qt5}
Summary:	Development tools for programs which uses QwtPlot3D Widget set
Group:		Development/Other
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{fakename}-qt5-devel = %{version}-%{release}
Provides:	%{fakename}-qt5-devel = %{version}-%{release}

# drop old and no more needed Qt4 libs
Obsoletes:	%{_lib}qwtplot3d-devel < 0.2.7-17

%description -n	%{libnamedev_qt5}
The %{libnamedev_qt5} package contains Qt5 libraries and header files for
developing applications that use %{fakename}-qt5.
%endif

#------------------------------------------------------------------------------
### Qt6 ###

%if %{with qt6}
%package -n	%{libname_qt6}
Summary:	Extended version of the original QwtPlot3D Qt6 library
Group:		System/Libraries

%description -n	%{libname_qt6}
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

%package -n	%{libnamedev_qt6}
Summary:	Development tools for programs which uses QwtPlot3D Widget set
Group:		Development/Other
Requires:	%{libname_qt6} = %{version}-%{release}
Provides:	%{fakename}-qt6-devel = %{version}-%{release}
Provides:	%{fakename}-qt6-devel = %{version}-%{release}

%description -n	%{libnamedev_qt6}
The %{libnamedev_qt6} package contains Qt6 libraries and header files for
developing applications that use %{fakename}-qt6.
%endif

#------------------------------------------------------------------------------

%prep
%setup -qc -n %{fakename}-%{commit}

# Unbundle gl2ps
rm -rf %{fakename}-%{commit}/3rdparty/gl2ps

cp -a %{fakename}-%{commit} %{fakename}-qt5
mv %{fakename}-%{commit} %{fakename}-qt6

%if %{with qt6}
pushd %{fakename}-qt6
%patch -P 0 -p1 -b .backup
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
%patch -P 1 -p1 -b .backup
popd
%endif

%build
%if %{with qt6}
pushd %{fakename}-qt6
export CXXFLAGS="%{build_cxxflags}"
%cmake \
 -DPKG_CONFIG_ARGN:STRING="%(pkg-config --cflags Qt6Gui) %(pkg-config --cflags Qt6Core) %(pkg-config --cflags Qt6OpenGL)" \
 -DCMAKE_SHARED_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -lGLU" \
 -DCMAKE_INSTALL_LIBDIR:PATH=%{_qt6_libdir} \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_qt6_headerdir}/%{fakename}-qt6
%cmake_build
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
export CXXFLAGS="%{build_cxxflags}"
%cmake \
 -DPKG_CONFIG_ARGN:STRING="%(pkg-config --cflags Qt5Gui) %(pkg-config --cflags Qt5Core) %(pkg-config --cflags Qt5OpenGL)" \
 -DCMAKE_SHARED_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -lGLU" \
 -DCMAKE_INSTALL_LIBDIR:PATH=%{_qt5_libdir} \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_qt5_headerdir}/%{fakename}-qt5
%cmake_build
popd
%endif

%install
%if %{with qt6}
pushd %{fakename}-qt6
%cmake_install
# Install executable examples files
mkdir -p %{buildroot}%{_libexecdir}/%{fakename}-qt6
install -pm 755 %{_vpath_builddir}/examples/simpleplot/simpleplot \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/axes/axes \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/enrichments/enrichments \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/autoswitch/autoswitch \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/mesh2/mesh2 \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/

mkdir -p %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6
install -pm 644 include/*  %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/
mv %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h.in %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MAJOR@|0|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MINOR@|3|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_PATCH@|0|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h

# Remove rpaths
chrpath -d %{buildroot}%{_libexecdir}/%{fakename}-qt6/*
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
%cmake_install
# Install executable examples files
mkdir -p %{buildroot}%{_libexecdir}/%{fakename}-qt5
install -pm 755 %{_vpath_builddir}/examples/simpleplot/simpleplot \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/axes/axes \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/enrichments/enrichments \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/autoswitch/autoswitch \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/mesh2/mesh2 \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/

mkdir -p %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5
install -pm 644 include/*  %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/
mv %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h.in %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MAJOR@|0|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MINOR@|3|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_PATCH@|0|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h

# Remove rpaths
chrpath -d %{buildroot}%{_libexecdir}/%{fakename}-qt5/*
popd
%endif

# Qt6
%if %{with qt6}
%files -n %{libname_qt6}
%license %{fakename}-qt6/COPYING %{fakename}-qt6/LICENSE
%doc %{fakename}-qt6/README.md
%{_qt6_libdir}/lib%{fakename}-qt6.so.%{major_qt6}{,.*}

%files -n %{libnamedev_qt6}
%{_qt6_headerdir}/%{fakename}-qt6/
%{_qt6_libdir}/lib%{fakename}-qt6.so
%{_libexecdir}/%{fakename}-qt6/
%endif
#

# Qt5
%if %{with qt5}
%files -n %{libname_qt5}
%license %{fakename}-qt5/COPYING %{fakename}-qt5/LICENSE
%doc %{fakename}-qt5/README.md
%{_qt5_libdir}/lib%{fakename}-qt5.so.%{major_qt5}{,.*}

%files -n %{libnamedev_qt5}
%{_qt5_headerdir}/%{fakename}-qt5/
%{_qt5_libdir}/lib%{fakename}-qt5.so
%{_libexecdir}/%{fakename}-qt5/
%endif
#


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 0.3.1a-2.git20210828.3.mga10
+ Revision: 2232038
- Mageia 10 Mass Rebuild

* Sun Dec 22 2024 pterjan <pterjan> 0.3.1a-2.git20210828.2.mga10
+ Revision: 2127817
- Rebuild for patchN deprecation

* Thu Oct 26 2023 daviddavid <daviddavid> 0.3.1a-2.git20210828.1.mga10
+ Revision: 2001904
- keep 0.3.1a version to match with old libqwtplot3d-qt5 and to not forcing to add an epoch
- new version: 0.3.0 (from SciDAVis github project)
  * https://github.com/SciDAVis/qwtplot3d
- obsolete/replace old libqwtplot3d-qt4 and libqwtplot3d-qt5
- add Qt6 support

* Sun Apr 03 2022 umeabot <umeabot> 0.2.7-16.mga9
+ Revision: 1841265
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 umeabot <umeabot> 0.2.7-15.mga8
+ Revision: 1514716
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.2.7-14.mga7
+ Revision: 1299115
- Mageia 7 Mass Rebuild

* Mon Feb 15 2016 umeabot <umeabot> 0.2.7-13.mga6
+ Revision: 961189
- Mageia 6 Mass Rebuild

* Mon Oct 19 2015 daviddavid <daviddavid> 0.2.7-12.mga6
+ Revision: 892868
- fix empty debugfiles (permissions of libraries must be 0755 instead of 0644)

* Wed Oct 15 2014 umeabot <umeabot> 0.2.7-11.mga5
+ Revision: 746277
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.7-10.mga5
+ Revision: 681741
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.2.7-9.mga4
+ Revision: 507340
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0.2.7-8.mga3
+ Revision: 358054
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 15 2012 fwang <fwang> 0.2.7-7.mga3
+ Revision: 305918
- fix libname
- link with glu
- build with latest glu
- cleanup spec

* Mon May 02 2011 mikala <mikala> 0.2.7-7.mga1
+ Revision: 94210
- Remove BuildRoot tag
- Use %%buildroot instead of $RPM_BUILD_ROOT
- Remove mdk macros
- imported package libqwtplot3d


* Fri Dec 10 2010 Oden Eriksson <oeriksson@mandriva.com> 0.2.7-6mdv2011.0
+ Revision: 620219
- the mass rebuild of 2010.0 packages

* Tue Aug 25 2009 Emmanuel Andry <eandry@mandriva.org> 0.2.7-5mdv2010.0
+ Revision: 421198
- add P1 to fix gcc44 build
- check major

* Tue Aug 05 2008 Funda Wang <fwang@mandriva.org> 0.2.7-4mdv2009.0
+ Revision: 263927
- fix license
- drop unneeded BR

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 0.2.7-3mdv2009.0
+ Revision: 240988
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Jul 21 2007 Funda Wang <fwang@mandriva.org> 0.2.7-1mdv2008.0
+ Revision: 54262
- fix file list
- New version

* Tue Apr 24 2007 Lenny Cartier <lenny@mandriva.org> 0.2.6-2mdv2008.0
+ Revision: 17950
- Rebuild

* Mon Apr 23 2007 Lenny Cartier <lenny@mandriva.org> 0.2.6-1mdv2008.0
+ Revision: 17656
- Update to 0.2.6


* Fri Jul 29 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.2.5-1mdk
- 0.2.5
- Fix qt path
- Fix BuildRequires

* Wed Mar 09 2005 Lenny Cartier <lenny@mandrakesoft.com> 0.2.4-0.beta.1mdk
- from Olivier Lahaye <olivier.lahaye1@free.Fr> : 
	- port spec to Mandrake 10.1

* Fri Feb 11 2005 Vitaly Lipatov <lav@altlinux.ru> 0.2.4-alt0.2beta
- move libraries to /usr/lib64, fix .so placement

* Mon Dec 27 2004 Vitaly Lipatov <lav@altlinux.ru> 0.2.4-alt0.1beta
- first build for ALT Linux Sisyphus

